@@ -14,6 +14,15 @@ import logging
 import shutil
 from typing import Callable, Optional
 from urllib import request
+try:
+    import cv2 as cv
+except ImportError as e:
+    cv = None
+
+try:
+    import cv2 as cv
+except ImportError as e:
+    cv = None
 
 
 __all__ = ["PathManager", "get_cache_dir", "file_lock"]
@@ -600,8 +609,6 @@ class ImageSourceIter(SourceIter):
     def __init__(self, src, exit_auto=True):
         super(ImageSourceIter, self).__init__(src, exit_auto)
 
-        import cv2 as cv
-
         self._index_sources()
         self.is_written = False
         self.save_f = None
@@ -713,6 +720,18 @@ class ImageSourceIter(SourceIter):
                     # clean up remove saved file.
                     os.remove(self.save_f)
 
+    def waitKey(self):
+        if self.video_mode:
+            cv.waitKey(1)
+        else:
+            cv.waitKey(0)
+
+
+def next_item(iter):
+    itm = next(iter)
+    if isinstance(itm, str):
+        itm = cv.imread(itm)
+    return itm
 
 class ImageSourceIterAsync(SourceIter):
     """
@@ -833,3 +852,10 @@ class ImageSourceIterAsync(SourceIter):
                 if self.save_f and os.path.exists(self.save_f):
                     # clean up remove saved file.
                     os.remove(self.save_f)
+
+
+def get_next_frame(iter):
+    itm = next(iter)
+    if os.path.isfile(itm):
+        itm = cv.imread(itm)
+    return itm
\ No newline at end of file
